# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/clickhouse/v1/backup_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2
from doublecloud.clickhouse.v1 import backup_pb2 as doublecloud_dot_clickhouse_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.doublecloud/clickhouse/v1/backup_service.proto\x12\x19\x64oublecloud.clickhouse.v1\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\x1a&doublecloud/clickhouse/v1/backup.proto\"/\n\x10GetBackupRequest\x12\x1b\n\tbackup_id\x18\x01 \x01(\tR\x08\x62\x61\x63kupId\"c\n\x12ListBackupsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x89\x01\n\x13ListBackupsResponse\x12;\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32!.doublecloud.clickhouse.v1.BackupR\x07\x62\x61\x63kups\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"H\n\x13\x43reateBackupRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"2\n\x13\x44\x65leteBackupRequest\x12\x1b\n\tbackup_id\x18\x01 \x01(\tR\x08\x62\x61\x63kupId2\xf7\x02\n\rBackupService\x12U\n\x03Get\x12+.doublecloud.clickhouse.v1.GetBackupRequest\x1a!.doublecloud.clickhouse.v1.Backup\x12\x65\n\x04List\x12-.doublecloud.clickhouse.v1.ListBackupsRequest\x1a..doublecloud.clickhouse.v1.ListBackupsResponse\x12S\n\x06\x43reate\x12..doublecloud.clickhouse.v1.CreateBackupRequest\x1a\x19.doublecloud.v1.Operation\x12S\n\x06\x44\x65lete\x12..doublecloud.clickhouse.v1.DeleteBackupRequest\x1a\x19.doublecloud.v1.OperationBAZ?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.clickhouse.v1.backup_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouse'
  _globals['_GETBACKUPREQUEST']._serialized_start=178
  _globals['_GETBACKUPREQUEST']._serialized_end=225
  _globals['_LISTBACKUPSREQUEST']._serialized_start=227
  _globals['_LISTBACKUPSREQUEST']._serialized_end=326
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=329
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=466
  _globals['_CREATEBACKUPREQUEST']._serialized_start=468
  _globals['_CREATEBACKUPREQUEST']._serialized_end=540
  _globals['_DELETEBACKUPREQUEST']._serialized_start=542
  _globals['_DELETEBACKUPREQUEST']._serialized_end=592
  _globals['_BACKUPSERVICE']._serialized_start=595
  _globals['_BACKUPSERVICE']._serialized_end=970
# @@protoc_insertion_point(module_scope)
