# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from doublecloud.transfer.v1 import endpoint_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.doublecloud/transfer/v1/endpoint_service.proto\x12\x17\x64oublecloud.transfer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a&doublecloud/transfer/v1/endpoint.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\"5\n\x12GetEndpointRequest\x12\x1f\n\x0b\x65ndpoint_id\x18\x01 \x01(\tR\nendpointId\"a\n\x14ListEndpointsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12*\n\x04page\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x04page\"\x8f\x01\n\x15ListEndpointsResponse\x12?\n\tendpoints\x18\x01 \x03(\x0b\x32!.doublecloud.transfer.v1.EndpointR\tendpoints\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"\xc2\x02\n\x15\x43reateEndpointRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12R\n\x06labels\x18\x04 \x03(\x0b\x32:.doublecloud.transfer.v1.CreateEndpointRequest.LabelsEntryR\x06labels\x12\x45\n\x08settings\x18\x34 \x01(\x0b\x32).doublecloud.transfer.v1.EndpointSettingsR\x08settings\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"\xc4\x02\n\x15UpdateEndpointRequest\x12\x1f\n\x0b\x65ndpoint_id\x18\n \x01(\tR\nendpointId\x12\x12\n\x04name\x18\x0b \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x0c \x01(\tR\x0b\x64\x65scription\x12R\n\x06labels\x18\r \x03(\x0b\x32:.doublecloud.transfer.v1.UpdateEndpointRequest.LabelsEntryR\x06labels\x12\x45\n\x08settings\x18\x34 \x01(\x0b\x32).doublecloud.transfer.v1.EndpointSettingsR\x08settings\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"8\n\x15\x44\x65leteEndpointRequest\x12\x1f\n\x0b\x65ndpoint_id\x18\x01 \x01(\tR\nendpointId2\x80\x05\n\x0f\x45ndpointService\x12y\n\x03Get\x12+.doublecloud.transfer.v1.GetEndpointRequest\x1a!.doublecloud.transfer.v1.Endpoint\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/endpoint/{endpoint_id}\x12\x8e\x01\n\x04List\x12-.doublecloud.transfer.v1.ListEndpointsRequest\x1a..doublecloud.transfer.v1.ListEndpointsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/endpoints/list/{project_id}\x12l\n\x06\x43reate\x12..doublecloud.transfer.v1.CreateEndpointRequest\x1a\x19.doublecloud.v1.Operation\"\x17\x82\xd3\xe4\x93\x02\x11:\x01*\"\x0c/v1/endpoint\x12z\n\x06Update\x12..doublecloud.transfer.v1.UpdateEndpointRequest\x1a\x19.doublecloud.v1.Operation\"%\x82\xd3\xe4\x93\x02\x1f:\x01*2\x1a/v1/endpoint/{endpoint_id}\x12w\n\x06\x44\x65lete\x12..doublecloud.transfer.v1.DeleteEndpointRequest\x1a\x19.doublecloud.v1.Operation\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/v1/endpoint/{endpoint_id}B=Z;github.com/doublecloud/api/doublecloud/transfer/v1;transferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/doublecloud/api/doublecloud/transfer/v1;transfer'
  _CREATEENDPOINTREQUEST_LABELSENTRY._options = None
  _CREATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEENDPOINTREQUEST_LABELSENTRY._options = None
  _UPDATEENDPOINTREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _ENDPOINTSERVICE.methods_by_name['Get']._options = None
  _ENDPOINTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/endpoint/{endpoint_id}'
  _ENDPOINTSERVICE.methods_by_name['List']._options = None
  _ENDPOINTSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/v1/endpoints/list/{project_id}'
  _ENDPOINTSERVICE.methods_by_name['Create']._options = None
  _ENDPOINTSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\021:\001*\"\014/v1/endpoint'
  _ENDPOINTSERVICE.methods_by_name['Update']._options = None
  _ENDPOINTSERVICE.methods_by_name['Update']._serialized_options = b'\202\323\344\223\002\037:\001*2\032/v1/endpoint/{endpoint_id}'
  _ENDPOINTSERVICE.methods_by_name['Delete']._options = None
  _ENDPOINTSERVICE.methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002\034*\032/v1/endpoint/{endpoint_id}'
  _globals['_GETENDPOINTREQUEST']._serialized_start=240
  _globals['_GETENDPOINTREQUEST']._serialized_end=293
  _globals['_LISTENDPOINTSREQUEST']._serialized_start=295
  _globals['_LISTENDPOINTSREQUEST']._serialized_end=392
  _globals['_LISTENDPOINTSRESPONSE']._serialized_start=395
  _globals['_LISTENDPOINTSRESPONSE']._serialized_end=538
  _globals['_CREATEENDPOINTREQUEST']._serialized_start=541
  _globals['_CREATEENDPOINTREQUEST']._serialized_end=863
  _globals['_CREATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=806
  _globals['_CREATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=863
  _globals['_UPDATEENDPOINTREQUEST']._serialized_start=866
  _globals['_UPDATEENDPOINTREQUEST']._serialized_end=1190
  _globals['_UPDATEENDPOINTREQUEST_LABELSENTRY']._serialized_start=806
  _globals['_UPDATEENDPOINTREQUEST_LABELSENTRY']._serialized_end=863
  _globals['_DELETEENDPOINTREQUEST']._serialized_start=1192
  _globals['_DELETEENDPOINTREQUEST']._serialized_end=1248
  _globals['_ENDPOINTSERVICE']._serialized_start=1251
  _globals['_ENDPOINTSERVICE']._serialized_end=1891
# @@protoc_insertion_point(module_scope)
