# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/network/v1/network_connection_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.network.v1 import network_connection_pb2 as doublecloud_dot_network_dot_v1_dot_network__connection__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7doublecloud/network/v1/network_connection_service.proto\x12\x16\x64oublecloud.network.v1\x1a/doublecloud/network/v1/network_connection.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\"Q\n\x1bGetNetworkConnectionRequest\x12\x32\n\x15network_connection_id\x18\x01 \x01(\tR\x13networkConnectionId\"n\n\x1dListNetworkConnectionsRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\xb3\x01\n\x1eListNetworkConnectionsResponse\x12Z\n\x13network_connections\x18\x01 \x03(\x0b\x32).doublecloud.network.v1.NetworkConnectionR\x12networkConnections\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"\xba\x01\n\x1e\x43reateNetworkConnectionRequest\x12\x1d\n\nnetwork_id\x18\x01 \x01(\tR\tnetworkId\x12M\n\x03\x61ws\x18\x03 \x01(\x0b\x32\x39.doublecloud.network.v1.CreateAWSNetworkConnectionRequestH\x00R\x03\x61ws\x12 \n\x0b\x64\x65scription\x18\x06 \x01(\tR\x0b\x64\x65scriptionB\x08\n\x06params\"\x89\x01\n!CreateAWSNetworkConnectionRequest\x12\\\n\x07peering\x18\x01 \x01(\x0b\x32@.doublecloud.network.v1.CreateAWSNetworkConnectionPeeringRequestH\x00R\x07peeringB\x06\n\x04type\"\xcd\x01\n(CreateAWSNetworkConnectionPeeringRequest\x12\x15\n\x06vpc_id\x18\x01 \x01(\tR\x05vpcId\x12\x1d\n\naccount_id\x18\x02 \x01(\tR\taccountId\x12\x1b\n\tregion_id\x18\x03 \x01(\tR\x08regionId\x12&\n\x0fipv4_cidr_block\x18\x04 \x01(\tR\ripv4CidrBlock\x12&\n\x0fipv6_cidr_block\x18\x05 \x01(\tR\ripv6CidrBlock\"T\n\x1e\x44\x65leteNetworkConnectionRequest\x12\x32\n\x15network_connection_id\x18\x01 \x01(\tR\x13networkConnectionId\"v\n\x1eUpdateNetworkConnectionRequest\x12\x32\n\x15network_connection_id\x18\x01 \x01(\tR\x13networkConnectionId\x12 \n\x0b\x64\x65scription\x18\x02 \x01(\tR\x0b\x64\x65scription2\xb2\x03\n\x18NetworkConnectionService\x12\x65\n\x03Get\x12\x33.doublecloud.network.v1.GetNetworkConnectionRequest\x1a).doublecloud.network.v1.NetworkConnection\x12u\n\x04List\x12\x35.doublecloud.network.v1.ListNetworkConnectionsRequest\x1a\x36.doublecloud.network.v1.ListNetworkConnectionsResponse\x12[\n\x06\x43reate\x12\x36.doublecloud.network.v1.CreateNetworkConnectionRequest\x1a\x19.doublecloud.v1.Operation\x12[\n\x06\x44\x65lete\x12\x36.doublecloud.network.v1.DeleteNetworkConnectionRequest\x1a\x19.doublecloud.v1.OperationB;Z9github.com/doublecloud/api/doublecloud/network/v1;networkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.network.v1.network_connection_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/doublecloud/api/doublecloud/network/v1;network'
  _globals['_GETNETWORKCONNECTIONREQUEST']._serialized_start=193
  _globals['_GETNETWORKCONNECTIONREQUEST']._serialized_end=274
  _globals['_LISTNETWORKCONNECTIONSREQUEST']._serialized_start=276
  _globals['_LISTNETWORKCONNECTIONSREQUEST']._serialized_end=386
  _globals['_LISTNETWORKCONNECTIONSRESPONSE']._serialized_start=389
  _globals['_LISTNETWORKCONNECTIONSRESPONSE']._serialized_end=568
  _globals['_CREATENETWORKCONNECTIONREQUEST']._serialized_start=571
  _globals['_CREATENETWORKCONNECTIONREQUEST']._serialized_end=757
  _globals['_CREATEAWSNETWORKCONNECTIONREQUEST']._serialized_start=760
  _globals['_CREATEAWSNETWORKCONNECTIONREQUEST']._serialized_end=897
  _globals['_CREATEAWSNETWORKCONNECTIONPEERINGREQUEST']._serialized_start=900
  _globals['_CREATEAWSNETWORKCONNECTIONPEERINGREQUEST']._serialized_end=1105
  _globals['_DELETENETWORKCONNECTIONREQUEST']._serialized_start=1107
  _globals['_DELETENETWORKCONNECTIONREQUEST']._serialized_end=1191
  _globals['_UPDATENETWORKCONNECTIONREQUEST']._serialized_start=1193
  _globals['_UPDATENETWORKCONNECTIONREQUEST']._serialized_end=1311
  _globals['_NETWORKCONNECTIONSERVICE']._serialized_start=1314
  _globals['_NETWORKCONNECTIONSERVICE']._serialized_end=1748
# @@protoc_insertion_point(module_scope)
