# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/airbyte/bigquery_source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>doublecloud/transfer/v1/endpoint/airbyte/bigquery_source.proto\x12(doublecloud.transfer.v1.endpoint.airbyte\"y\n\x0e\x42igQuerySource\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x1d\n\ndataset_id\x18\x02 \x01(\tR\tdatasetId\x12)\n\x10\x63redentials_json\x18\x03 \x01(\tR\x0f\x63redentialsJsonBVZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyteb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.airbyte.bigquery_source_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZTgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint/airbyte;endpoint_airbyte'
  _globals['_BIGQUERYSOURCE']._serialized_start=108
  _globals['_BIGQUERYSOURCE']._serialized_end=229
# @@protoc_insertion_point(module_scope)
