# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/topic_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2
from doublecloud.kafka.v1 import topic_pb2 as doublecloud_dot_kafka_dot_v1_dot_topic__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(doublecloud/kafka/v1/topic_service.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\x1a doublecloud/kafka/v1/topic.proto\"O\n\x0fGetTopicRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1d\n\ntopic_name\x18\x02 \x01(\tR\ttopicName\"b\n\x11ListTopicsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x80\x01\n\x12ListTopicsResponse\x12\x33\n\x06topics\x18\x01 \x03(\x0b\x32\x1b.doublecloud.kafka.v1.TopicR\x06topics\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"s\n\x12\x43reateTopicRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12>\n\ntopic_spec\x18\x02 \x01(\x0b\x32\x1f.doublecloud.kafka.v1.TopicSpecR\ttopicSpec\"\x92\x01\n\x12UpdateTopicRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1d\n\ntopic_name\x18\x02 \x01(\tR\ttopicName\x12>\n\ntopic_spec\x18\x03 \x01(\x0b\x32\x1f.doublecloud.kafka.v1.TopicSpecR\ttopicSpec\"R\n\x12\x44\x65leteTopicRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1d\n\ntopic_name\x18\x02 \x01(\tR\ttopicName2\xa1\x03\n\x0cTopicService\x12I\n\x03Get\x12%.doublecloud.kafka.v1.GetTopicRequest\x1a\x1b.doublecloud.kafka.v1.Topic\x12Y\n\x04List\x12\'.doublecloud.kafka.v1.ListTopicsRequest\x1a(.doublecloud.kafka.v1.ListTopicsResponse\x12M\n\x06\x43reate\x12(.doublecloud.kafka.v1.CreateTopicRequest\x1a\x19.doublecloud.v1.Operation\x12M\n\x06Update\x12(.doublecloud.kafka.v1.UpdateTopicRequest\x1a\x19.doublecloud.v1.Operation\x12M\n\x06\x44\x65lete\x12(.doublecloud.kafka.v1.DeleteTopicRequest\x1a\x19.doublecloud.v1.OperationB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.topic_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_GETTOPICREQUEST']._serialized_start=161
  _globals['_GETTOPICREQUEST']._serialized_end=240
  _globals['_LISTTOPICSREQUEST']._serialized_start=242
  _globals['_LISTTOPICSREQUEST']._serialized_end=340
  _globals['_LISTTOPICSRESPONSE']._serialized_start=343
  _globals['_LISTTOPICSRESPONSE']._serialized_end=471
  _globals['_CREATETOPICREQUEST']._serialized_start=473
  _globals['_CREATETOPICREQUEST']._serialized_end=588
  _globals['_UPDATETOPICREQUEST']._serialized_start=591
  _globals['_UPDATETOPICREQUEST']._serialized_end=737
  _globals['_DELETETOPICREQUEST']._serialized_start=739
  _globals['_DELETETOPICREQUEST']._serialized_end=821
  _globals['_TOPICSERVICE']._serialized_start=824
  _globals['_TOPICSERVICE']._serialized_end=1241
# @@protoc_insertion_point(module_scope)
