# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.visualization.v1 import workbook_service_pb2 as doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2


class WorkbookServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/Get',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookRequest.SerializeToString,
                response_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/Create',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/Update',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/Delete',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.GetConnection = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/GetConnection',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionResponse.FromString,
                )
        self.CreateConnection = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/CreateConnection',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateConnection = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/UpdateConnection',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteConnection = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/DeleteConnection',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.AdviseDatasetFields = channel.unary_unary(
                '/doublecloud.visualization.v1.WorkbookService/AdviseDatasetFields',
                request_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsRequest.SerializeToString,
                response_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsResponse.FromString,
                )


class WorkbookServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Workbook operations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnection(self, request, context):
        """Connections operations
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteConnection(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AdviseDatasetFields(self, request, context):
        """List all direct fields of dataset with configured data source
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WorkbookServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookRequest.FromString,
                    response_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnection,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionResponse.SerializeToString,
            ),
            'CreateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateConnection,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateConnection,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteConnection': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteConnection,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AdviseDatasetFields': grpc.unary_unary_rpc_method_handler(
                    servicer.AdviseDatasetFields,
                    request_deserializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsRequest.FromString,
                    response_serializer=doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'doublecloud.visualization.v1.WorkbookService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WorkbookService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/Get',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookRequest.SerializeToString,
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/Create',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/Update',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/Delete',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/GetConnection',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionRequest.SerializeToString,
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.GetWorkbookConnectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/CreateConnection',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.CreateWorkbookConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/UpdateConnection',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.UpdateWorkbookConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteConnection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/DeleteConnection',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.DeleteWorkbookConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AdviseDatasetFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.visualization.v1.WorkbookService/AdviseDatasetFields',
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsRequest.SerializeToString,
            doublecloud_dot_visualization_dot_v1_dot_workbook__service__pb2.AdviseDatasetFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
