# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/postgres.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/doublecloud/transfer/v1/endpoint/postgres.proto\x12 doublecloud.transfer.v1.endpoint\x1a-doublecloud/transfer/v1/endpoint/common.proto\"\x8b\x0c\n\x1ePostgresObjectTransferSettings\x12Q\n\x08sequence\x18\x01 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x08sequence\x12\x61\n\x11sequence_owned_by\x18\x02 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x0fsequenceOwnedBy\x12X\n\x0csequence_set\x18\x12 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x0bsequenceSet\x12K\n\x05table\x18\x03 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x05table\x12V\n\x0bprimary_key\x18\x04 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\nprimaryKey\x12Z\n\rfk_constraint\x18\x05 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x0c\x66kConstraint\x12\\\n\x0e\x64\x65\x66\x61ult_values\x18\x06 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\rdefaultValues\x12U\n\nconstraint\x18\x07 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\nconstraint\x12K\n\x05index\x18\x08 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x05index\x12I\n\x04view\x18\t \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04view\x12\x62\n\x11materialized_view\x18\x11 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x10materializedView\x12Q\n\x08\x66unction\x18\n \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x08\x66unction\x12O\n\x07trigger\x18\x0b \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x07trigger\x12I\n\x04type\x18\x0c \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04type\x12I\n\x04rule\x18\r \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04rule\x12S\n\tcollation\x18\x0e \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\tcollation\x12M\n\x06policy\x18\x0f \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x06policy\x12I\n\x04\x63\x61st\x18\x10 \x01(\x0e\x32\x35.doublecloud.transfer.v1.endpoint.ObjectTransferStageR\x04\x63\x61st\"\x83\x01\n\x11OnPremisePostgres\x12\x14\n\x05hosts\x18\x05 \x03(\tR\x05hosts\x12\x12\n\x04port\x18\x02 \x01(\x03R\x04port\x12\x44\n\x08tls_mode\x18\x06 \x01(\x0b\x32).doublecloud.transfer.v1.endpoint.TLSModeR\x07tlsMode\"x\n\x12PostgresConnection\x12T\n\non_premise\x18\x02 \x01(\x0b\x32\x33.doublecloud.transfer.v1.endpoint.OnPremisePostgresH\x00R\tonPremiseB\x0c\n\nconnection\"\xfc\x03\n\x0ePostgresSource\x12T\n\nconnection\x18\x01 \x01(\x0b\x32\x34.doublecloud.transfer.v1.endpoint.PostgresConnectionR\nconnection\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12\x12\n\x04user\x18\x03 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12%\n\x0einclude_tables\x18\x05 \x03(\tR\rincludeTables\x12%\n\x0e\x65xclude_tables\x18\x06 \x03(\tR\rexcludeTables\x12-\n\x13slot_byte_lag_limit\x18\x08 \x01(\x03R\x10slotByteLagLimit\x12%\n\x0eservice_schema\x18\t \x01(\tR\rserviceSchema\x12z\n\x18object_transfer_settings\x18\r \x01(\x0b\x32@.doublecloud.transfer.v1.endpoint.PostgresObjectTransferSettingsR\x16objectTransferSettings\"\xdd\x02\n\x0ePostgresTarget\x12T\n\nconnection\x18\x01 \x01(\x0b\x32\x34.doublecloud.transfer.v1.endpoint.PostgresConnectionR\nconnection\x12\'\n\x0fsecurity_groups\x18\x07 \x03(\tR\x0esecurityGroups\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12\x12\n\x04user\x18\x03 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12V\n\x0e\x63leanup_policy\x18\x05 \x01(\x0e\x32/.doublecloud.transfer.v1.endpoint.CleanupPolicyR\rcleanupPolicyBFZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.postgres_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_POSTGRESOBJECTTRANSFERSETTINGS']._serialized_start=133
  _globals['_POSTGRESOBJECTTRANSFERSETTINGS']._serialized_end=1680
  _globals['_ONPREMISEPOSTGRES']._serialized_start=1683
  _globals['_ONPREMISEPOSTGRES']._serialized_end=1814
  _globals['_POSTGRESCONNECTION']._serialized_start=1816
  _globals['_POSTGRESCONNECTION']._serialized_end=1936
  _globals['_POSTGRESSOURCE']._serialized_start=1939
  _globals['_POSTGRESSOURCE']._serialized_end=2447
  _globals['_POSTGRESTARGET']._serialized_start=2450
  _globals['_POSTGRESTARGET']._serialized_end=2799
# @@protoc_insertion_point(module_scope)
