# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/kafka/v1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from doublecloud.v1 import cluster_pb2 as doublecloud_dot_v1_dot_cluster__pb2
from doublecloud.v1 import maintenance_pb2 as doublecloud_dot_v1_dot_maintenance__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2
from doublecloud.v1 import paging_pb2 as doublecloud_dot_v1_dot_paging__pb2
from doublecloud.kafka.v1 import cluster_pb2 as doublecloud_dot_kafka_dot_v1_dot_cluster__pb2
from doublecloud.kafka.v1 import config_pb2 as doublecloud_dot_kafka_dot_v1_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*doublecloud/kafka/v1/cluster_service.proto\x12\x14\x64oublecloud.kafka.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1c\x64oublecloud/v1/cluster.proto\x1a doublecloud/v1/maintenance.proto\x1a\x1e\x64oublecloud/v1/operation.proto\x1a\x1b\x64oublecloud/v1/paging.proto\x1a\"doublecloud/kafka/v1/cluster.proto\x1a!doublecloud/kafka/v1/config.proto\"P\n\x11GetClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x1c\n\tsensitive\x18\x02 \x01(\x08R\tsensitive\"\x9b\x01\n\x13ListClustersRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\x12\x35\n\x04view\x18\x03 \x01(\x0e\x32!.doublecloud.kafka.v1.ClusterViewR\x04view\"\x88\x01\n\x14ListClustersResponse\x12\x39\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\x1d.doublecloud.kafka.v1.ClusterR\x08\x63lusters\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"\xae\x04\n\x14\x43reateClusterRequest\x12\x1d\n\nproject_id\x18\x01 \x01(\tR\tprojectId\x12\x1d\n\ncloud_type\x18\x02 \x01(\tR\tcloudType\x12\x1b\n\tregion_id\x18\x03 \x01(\tR\x08regionId\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x05 \x01(\tR\x0b\x64\x65scription\x12\x18\n\x07version\x18\x06 \x01(\tR\x07version\x12\x44\n\tresources\x18\x07 \x01(\x0b\x32&.doublecloud.kafka.v1.ClusterResourcesR\tresources\x12.\n\x06\x61\x63\x63\x65ss\x18\x08 \x01(\x0b\x32\x16.doublecloud.v1.AccessR\x06\x61\x63\x63\x65ss\x12>\n\nencryption\x18\t \x01(\x0b\x32\x1e.doublecloud.v1.DataEncryptionR\nencryption\x12\x1d\n\nnetwork_id\x18\n \x01(\tR\tnetworkId\x12P\n\x12maintenance_window\x18\x0b \x01(\x0b\x32!.doublecloud.v1.MaintenanceWindowR\x11maintenanceWindow\x12\x44\n\x0ckafka_config\x18\x0c \x01(\x0b\x32!.doublecloud.kafka.v1.KafkaConfigR\x0bkafkaConfig\"\x93\x03\n\x14UpdateClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\x12\x18\n\x07version\x18\x04 \x01(\tR\x07version\x12\x44\n\tresources\x18\x05 \x01(\x0b\x32&.doublecloud.kafka.v1.ClusterResourcesR\tresources\x12.\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32\x16.doublecloud.v1.AccessR\x06\x61\x63\x63\x65ss\x12P\n\x12maintenance_window\x18\x07 \x01(\x0b\x32!.doublecloud.v1.MaintenanceWindowR\x11maintenanceWindow\x12\x44\n\x0ckafka_config\x18\x08 \x01(\x0b\x32!.doublecloud.kafka.v1.KafkaConfigR\x0bkafkaConfig\"5\n\x14\x44\x65leteClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\"?\n\x1eResetClusterCredentialsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\"h\n\x17ListClusterHostsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x83\x01\n\x18ListClusterHostsResponse\x12\x30\n\x05hosts\x18\x01 \x03(\x0b\x32\x1a.doublecloud.kafka.v1.HostR\x05hosts\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage\"4\n\x13StartClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\"3\n\x12StopClusterRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\"\xd0\x01\n\x1cRescheduleMaintenanceRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12G\n\x0freschedule_type\x18\x02 \x01(\x0e\x32\x1e.doublecloud.v1.RescheduleTypeR\x0erescheduleType\x12H\n\x12\x64\x65layed_until_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x64\x65layedUntilTime\"m\n\x1cListClusterOperationsRequest\x12\x1d\n\ncluster_id\x18\x01 \x01(\tR\tclusterId\x12.\n\x06paging\x18\x02 \x01(\x0b\x32\x16.doublecloud.v1.PagingR\x06paging\"\x91\x01\n\x1dListClusterOperationsResponse\x12\x39\n\noperations\x18\x01 \x03(\x0b\x32\x19.doublecloud.v1.OperationR\noperations\x12\x35\n\tnext_page\x18\x02 \x01(\x0b\x32\x18.doublecloud.v1.NextPageR\x08nextPage*V\n\x0b\x43lusterView\x12\x18\n\x14\x43LUSTER_VIEW_INVALID\x10\x00\x12\x16\n\x12\x43LUSTER_VIEW_BASIC\x10\x01\x12\x15\n\x11\x43LUSTER_VIEW_FULL\x10\x02\x32\x81\x08\n\x0e\x43lusterService\x12M\n\x03Get\x12\'.doublecloud.kafka.v1.GetClusterRequest\x1a\x1d.doublecloud.kafka.v1.Cluster\x12]\n\x04List\x12).doublecloud.kafka.v1.ListClustersRequest\x1a*.doublecloud.kafka.v1.ListClustersResponse\x12O\n\x06\x43reate\x12*.doublecloud.kafka.v1.CreateClusterRequest\x1a\x19.doublecloud.v1.Operation\x12O\n\x06Update\x12*.doublecloud.kafka.v1.UpdateClusterRequest\x1a\x19.doublecloud.v1.Operation\x12O\n\x06\x44\x65lete\x12*.doublecloud.kafka.v1.DeleteClusterRequest\x1a\x19.doublecloud.v1.Operation\x12\x63\n\x10ResetCredentials\x12\x34.doublecloud.kafka.v1.ResetClusterCredentialsRequest\x1a\x19.doublecloud.v1.Operation\x12j\n\tListHosts\x12-.doublecloud.kafka.v1.ListClusterHostsRequest\x1a..doublecloud.kafka.v1.ListClusterHostsResponse\x12M\n\x05Start\x12).doublecloud.kafka.v1.StartClusterRequest\x1a\x19.doublecloud.v1.Operation\x12K\n\x04Stop\x12(.doublecloud.kafka.v1.StopClusterRequest\x1a\x19.doublecloud.v1.Operation\x12\x66\n\x15RescheduleMaintenance\x12\x32.doublecloud.kafka.v1.RescheduleMaintenanceRequest\x1a\x19.doublecloud.v1.Operation\x12y\n\x0eListOperations\x12\x32.doublecloud.kafka.v1.ListClusterOperationsRequest\x1a\x33.doublecloud.kafka.v1.ListClusterOperationsResponseB7Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafkab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.kafka.v1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/doublecloud/api/doublecloud/kafka/v1;kafka'
  _globals['_CLUSTERVIEW']._serialized_start=2580
  _globals['_CLUSTERVIEW']._serialized_end=2666
  _globals['_GETCLUSTERREQUEST']._serialized_start=297
  _globals['_GETCLUSTERREQUEST']._serialized_end=377
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=380
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=535
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=538
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=674
  _globals['_CREATECLUSTERREQUEST']._serialized_start=677
  _globals['_CREATECLUSTERREQUEST']._serialized_end=1235
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1238
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=1641
  _globals['_DELETECLUSTERREQUEST']._serialized_start=1643
  _globals['_DELETECLUSTERREQUEST']._serialized_end=1696
  _globals['_RESETCLUSTERCREDENTIALSREQUEST']._serialized_start=1698
  _globals['_RESETCLUSTERCREDENTIALSREQUEST']._serialized_end=1761
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_start=1763
  _globals['_LISTCLUSTERHOSTSREQUEST']._serialized_end=1867
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_start=1870
  _globals['_LISTCLUSTERHOSTSRESPONSE']._serialized_end=2001
  _globals['_STARTCLUSTERREQUEST']._serialized_start=2003
  _globals['_STARTCLUSTERREQUEST']._serialized_end=2055
  _globals['_STOPCLUSTERREQUEST']._serialized_start=2057
  _globals['_STOPCLUSTERREQUEST']._serialized_end=2108
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_start=2111
  _globals['_RESCHEDULEMAINTENANCEREQUEST']._serialized_end=2319
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_start=2321
  _globals['_LISTCLUSTEROPERATIONSREQUEST']._serialized_end=2430
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_start=2433
  _globals['_LISTCLUSTEROPERATIONSRESPONSE']._serialized_end=2578
  _globals['_CLUSTERSERVICE']._serialized_start=2669
  _globals['_CLUSTERSERVICE']._serialized_end=3694
# @@protoc_insertion_point(module_scope)
