# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/transfer/v1/endpoint/mongo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from doublecloud.transfer.v1.endpoint import common_pb2 as doublecloud_dot_transfer_dot_v1_dot_endpoint_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,doublecloud/transfer/v1/endpoint/mongo.proto\x12 doublecloud.transfer.v1.endpoint\x1a-doublecloud/transfer/v1/endpoint/common.proto\"\xa1\x01\n\x0eOnPremiseMongo\x12\x14\n\x05hosts\x18\x01 \x03(\tR\x05hosts\x12\x12\n\x04port\x18\x02 \x01(\x03R\x04port\x12\x44\n\x08tls_mode\x18\x06 \x01(\x0b\x32).doublecloud.transfer.v1.endpoint.TLSModeR\x07tlsMode\x12\x1f\n\x0breplica_set\x18\x05 \x01(\tR\nreplicaSet\"\xf1\x01\n\x16MongoConnectionOptions\x12Q\n\non_premise\x18\x02 \x01(\x0b\x32\x30.doublecloud.transfer.v1.endpoint.OnPremiseMongoH\x00R\tonPremise\x12\x12\n\x04user\x18\x03 \x01(\tR\x04user\x12\x44\n\x08password\x18\x04 \x01(\x0b\x32(.doublecloud.transfer.v1.endpoint.SecretR\x08password\x12\x1f\n\x0b\x61uth_source\x18\x05 \x01(\tR\nauthSourceB\t\n\x07\x61\x64\x64ress\"\x8a\x01\n\x0fMongoConnection\x12i\n\x12\x63onnection_options\x18\x03 \x01(\x0b\x32\x38.doublecloud.transfer.v1.endpoint.MongoConnectionOptionsH\x00R\x11\x63onnectionOptionsB\x0c\n\nconnection\"_\n\x0fMongoCollection\x12#\n\rdatabase_name\x18\x01 \x01(\tR\x0c\x64\x61tabaseName\x12\'\n\x0f\x63ollection_name\x18\x02 \x01(\tR\x0e\x63ollectionName\"\xd5\x02\n\x0bMongoSource\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MongoConnectionR\nconnection\x12S\n\x0b\x63ollections\x18\x06 \x03(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MongoCollectionR\x0b\x63ollections\x12\x64\n\x14\x65xcluded_collections\x18\x07 \x03(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MongoCollectionR\x13\x65xcludedCollections\x12\x38\n\x18secondary_preferred_mode\x18\x08 \x01(\x08R\x16secondaryPreferredMode\"\xd4\x01\n\x0bMongoTarget\x12Q\n\nconnection\x18\x01 \x01(\x0b\x32\x31.doublecloud.transfer.v1.endpoint.MongoConnectionR\nconnection\x12\x1a\n\x08\x64\x61tabase\x18\x02 \x01(\tR\x08\x64\x61tabase\x12V\n\x0e\x63leanup_policy\x18\x06 \x01(\x0e\x32/.doublecloud.transfer.v1.endpoint.CleanupPolicyR\rcleanupPolicyBFZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.transfer.v1.endpoint.mongo_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZDgithub.com/doublecloud/api/doublecloud/transfer/v1/endpoint;endpoint'
  _globals['_ONPREMISEMONGO']._serialized_start=130
  _globals['_ONPREMISEMONGO']._serialized_end=291
  _globals['_MONGOCONNECTIONOPTIONS']._serialized_start=294
  _globals['_MONGOCONNECTIONOPTIONS']._serialized_end=535
  _globals['_MONGOCONNECTION']._serialized_start=538
  _globals['_MONGOCONNECTION']._serialized_end=676
  _globals['_MONGOCOLLECTION']._serialized_start=678
  _globals['_MONGOCOLLECTION']._serialized_end=773
  _globals['_MONGOSOURCE']._serialized_start=776
  _globals['_MONGOSOURCE']._serialized_end=1117
  _globals['_MONGOTARGET']._serialized_start=1120
  _globals['_MONGOTARGET']._serialized_end=1332
# @@protoc_insertion_point(module_scope)
