# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from doublecloud.network.v1 import network_connection_pb2 as doublecloud_dot_network_dot_v1_dot_network__connection__pb2
from doublecloud.network.v1 import network_connection_service_pb2 as doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2
from doublecloud.v1 import operation_pb2 as doublecloud_dot_v1_dot_operation__pb2


class NetworkConnectionServiceStub(object):
    """A set of methods for managing Networks Connection.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/doublecloud.network.v1.NetworkConnectionService/Get',
                request_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.GetNetworkConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__pb2.NetworkConnection.FromString,
                )
        self.List = channel.unary_unary(
                '/doublecloud.network.v1.NetworkConnectionService/List',
                request_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsRequest.SerializeToString,
                response_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/doublecloud.network.v1.NetworkConnectionService/Create',
                request_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.CreateNetworkConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/doublecloud.network.v1.NetworkConnectionService/Delete',
                request_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.DeleteNetworkConnectionRequest.SerializeToString,
                response_deserializer=doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class NetworkConnectionServiceServicer(object):
    """A set of methods for managing Networks Connection.
    """

    def Get(self, request, context):
        """Returns the specified Network Connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves a list of Network Connections of the specified Project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a Network Connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified Network Connection.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NetworkConnectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.GetNetworkConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__pb2.NetworkConnection.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsRequest.FromString,
                    response_serializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.CreateNetworkConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.DeleteNetworkConnectionRequest.FromString,
                    response_serializer=doublecloud_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'doublecloud.network.v1.NetworkConnectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NetworkConnectionService(object):
    """A set of methods for managing Networks Connection.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.network.v1.NetworkConnectionService/Get',
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.GetNetworkConnectionRequest.SerializeToString,
            doublecloud_dot_network_dot_v1_dot_network__connection__pb2.NetworkConnection.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.network.v1.NetworkConnectionService/List',
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsRequest.SerializeToString,
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.ListNetworkConnectionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.network.v1.NetworkConnectionService/Create',
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.CreateNetworkConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/doublecloud.network.v1.NetworkConnectionService/Delete',
            doublecloud_dot_network_dot_v1_dot_network__connection__service__pb2.DeleteNetworkConnectionRequest.SerializeToString,
            doublecloud_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
