# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: doublecloud/clickhouse/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from doublecloud.clickhouse.v1 import config_pb2 as doublecloud_dot_clickhouse_dot_v1_dot_config__pb2
from doublecloud.v1 import cluster_pb2 as doublecloud_dot_v1_dot_cluster__pb2
from doublecloud.v1 import maintenance_pb2 as doublecloud_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'doublecloud/clickhouse/v1/cluster.proto\x12\x19\x64oublecloud.clickhouse.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a&doublecloud/clickhouse/v1/config.proto\x1a\x1c\x64oublecloud/v1/cluster.proto\x1a doublecloud/v1/maintenance.proto\"\xd7\x07\n\x07\x43luster\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1d\n\ncloud_type\x18\x03 \x01(\tR\tcloudType\x12\x1b\n\tregion_id\x18\x04 \x01(\tR\x08regionId\x12;\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12\x12\n\x04name\x18\x06 \x01(\tR\x04name\x12 \n\x0b\x64\x65scription\x18\x07 \x01(\tR\x0b\x64\x65scription\x12\x35\n\x06status\x18\x08 \x01(\x0e\x32\x1d.doublecloud.v1.ClusterStatusR\x06status\x12\x18\n\x07version\x18\t \x01(\tR\x07version\x12I\n\tresources\x18\n \x01(\x0b\x32+.doublecloud.clickhouse.v1.ClusterResourcesR\tresources\x12R\n\x0f\x63onnection_info\x18\x0b \x01(\x0b\x32).doublecloud.clickhouse.v1.ConnectionInfoR\x0e\x63onnectionInfo\x12.\n\x06\x61\x63\x63\x65ss\x18\x0c \x01(\x0b\x32\x16.doublecloud.v1.AccessR\x06\x61\x63\x63\x65ss\x12h\n\x17private_connection_info\x18\r \x01(\x0b\x32\x30.doublecloud.clickhouse.v1.PrivateConnectionInfoR\x15privateConnectionInfo\x12>\n\nencryption\x18\x0e \x01(\x0b\x32\x1e.doublecloud.v1.DataEncryptionR\nencryption\x12\x1d\n\nnetwork_id\x18\x0f \x01(\tR\tnetworkId\x12X\n\x11\x63lickhouse_config\x18\x10 \x01(\x0b\x32+.doublecloud.clickhouse.v1.ClickhouseConfigR\x10\x63lickhouseConfig\x12P\n\x12maintenance_window\x18\x11 \x01(\x0b\x32!.doublecloud.v1.MaintenanceWindowR\x11maintenanceWindow\x12Y\n\x15maintenance_operation\x18\x12 \x01(\x0b\x32$.doublecloud.v1.MaintenanceOperationR\x14maintenanceOperation\"\xe1\x02\n\x10\x43lusterResources\x12V\n\nclickhouse\x18\x01 \x01(\x0b\x32\x36.doublecloud.clickhouse.v1.ClusterResources.ClickhouseR\nclickhouse\x1a\xf4\x01\n\nClickhouse\x12,\n\x12resource_preset_id\x18\x01 \x01(\tR\x10resourcePresetId\x12\x38\n\tdisk_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x08\x64iskSize\x12@\n\rreplica_count\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0creplicaCount\x12<\n\x0bshard_count\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\nshardCount\"\xd1\x02\n\x0e\x43onnectionInfo\x12\x12\n\x04host\x18\x01 \x01(\tR\x04host\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12:\n\nhttps_port\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\thttpsPort\x12\x43\n\x0ftcp_port_secure\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\rtcpPortSecure\x12\'\n\x0fnative_protocol\x18\x06 \x01(\tR\x0enativeProtocol\x12\x1b\n\thttps_uri\x18\x07 \x01(\tR\x08httpsUri\x12\x19\n\x08jdbc_uri\x18\x08 \x01(\tR\x07jdbcUri\x12\x19\n\x08odbc_uri\x18\t \x01(\tR\x07odbcUri\"\xd8\x02\n\x15PrivateConnectionInfo\x12\x12\n\x04host\x18\x01 \x01(\tR\x04host\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12:\n\nhttps_port\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\thttpsPort\x12\x43\n\x0ftcp_port_secure\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\rtcpPortSecure\x12\'\n\x0fnative_protocol\x18\x06 \x01(\tR\x0enativeProtocol\x12\x1b\n\thttps_uri\x18\x07 \x01(\tR\x08httpsUri\x12\x19\n\x08jdbc_uri\x18\x08 \x01(\tR\x07jdbcUri\x12\x19\n\x08odbc_uri\x18\t \x01(\tR\x07odbcUri\"{\n\x04Host\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\ncluster_id\x18\x02 \x01(\tR\tclusterId\x12\x1d\n\nshard_name\x18\x03 \x01(\tR\tshardName\x12!\n\x0cprivate_name\x18\x04 \x01(\tR\x0bprivateNameBAZ?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'doublecloud.clickhouse.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z?github.com/doublecloud/api/doublecloud/clickhouse/v1;clickhouse'
  _globals['_CLUSTER']._serialized_start=240
  _globals['_CLUSTER']._serialized_end=1223
  _globals['_CLUSTERRESOURCES']._serialized_start=1226
  _globals['_CLUSTERRESOURCES']._serialized_end=1579
  _globals['_CLUSTERRESOURCES_CLICKHOUSE']._serialized_start=1335
  _globals['_CLUSTERRESOURCES_CLICKHOUSE']._serialized_end=1579
  _globals['_CONNECTIONINFO']._serialized_start=1582
  _globals['_CONNECTIONINFO']._serialized_end=1919
  _globals['_PRIVATECONNECTIONINFO']._serialized_start=1922
  _globals['_PRIVATECONNECTIONINFO']._serialized_end=2266
  _globals['_HOST']._serialized_start=2268
  _globals['_HOST']._serialized_end=2391
# @@protoc_insertion_point(module_scope)
